@@ -11,6 +11,7 @@
 #include "SFCGAL/detail/io/WktWriter.h"
 
 #include "SFCGAL/algorithm/BoundaryVisitor.h"
+#include "SFCGAL/algorithm/centroid.h"
 #include "SFCGAL/algorithm/distance.h"
 #include "SFCGAL/algorithm/distance3d.h"
 
@@ -22,9 +23,6 @@
 
 namespace SFCGAL {
 
-///
-///
-///
 auto
 Geometry::asText(const int &numDecimals) const -> std::string
 {
@@ -54,9 +52,6 @@ Geometry::asWkb(boost::endian::order wkbOrder, bool asHex) const -> std::string
   writer.write(*this, wkbOrder);
   return oss.str();
 }
-///
-///
-///
 auto
 Geometry::envelope() const -> Envelope
 {
@@ -66,9 +61,6 @@ Geometry::envelope() const -> Envelope
   return box;
 }
 
-///
-///
-///
 auto
 Geometry::boundary() const -> std::unique_ptr<Geometry>
 {
@@ -77,27 +69,18 @@ Geometry::boundary() const -> std::unique_ptr<Geometry>
   return std::unique_ptr<Geometry>(visitor.releaseBoundary());
 }
 
-///
-///
-///
 auto
 Geometry::distance(const Geometry &other) const -> double
 {
   return algorithm::distance(*this, other);
 }
 
-///
-///
-///
 auto
 Geometry::distance3D(const Geometry &other) const -> double
 {
   return algorithm::distance3D(*this, other);
 }
 
-///
-///
-///
 void
 Geometry::round(const long &scale)
 {
@@ -105,18 +88,12 @@ Geometry::round(const long &scale)
   accept(roundTransform);
 }
 
-///
-///
-///
 auto
 Geometry::numGeometries() const -> size_t
 {
-  return 1;
+  return isEmpty() ? 0 : 1;
 }
 
-///
-///
-///
 auto
 Geometry::geometryN(size_t const &n) const -> const Geometry &
 {
@@ -125,9 +102,6 @@ Geometry::geometryN(size_t const &n) const -> const Geometry &
   return *this;
 }
 
-///
-///
-///
 auto
 Geometry::geometryN(size_t const &n) -> Geometry &
 {
@@ -136,9 +110,16 @@ Geometry::geometryN(size_t const &n) -> Geometry &
   return *this;
 }
 
-///
-///
-///
+void
+Geometry::setGeometryN(const Geometry &, size_t const &)
+{
+}
+
+void
+Geometry::setGeometryN(Geometry *, size_t const &)
+{
+}
+
 Geometry::Geometry() = default;
 
 auto
@@ -190,7 +171,23 @@ Geometry::almostEqual(const Geometry &other, const double tolerance) const
 
   return true;
 }
-///
+
+auto
+Geometry::centroid() const -> Point
+{
+  std::unique_ptr<Point> out = algorithm::centroid(*this);
+
+  return *(out.get());
+}
+
+auto
+Geometry::centroid3D() const -> Point
+{
+  std::unique_ptr<Point> out = algorithm::centroid3D(*this);
+
+  return *(out.get());
+}
+
 /// Function used to compare geometries
 /// FIXME
 /// Since we do not have (yet) a real "equals" operator, we only compare points
