@@ -27,8 +27,14 @@
 using namespace SFCGAL::detail;
 
 namespace SFCGAL::algorithm {
-//
-// Type of pa must be of larger dimension than type of pb
+
+// ----------------------------------------------------------------------------------
+// -- private interface
+// ----------------------------------------------------------------------------------
+/// @{
+/// @privatesection
+
+/// Type of pa must be of larger dimension than type of pb
 auto
 _intersects(const PrimitiveHandle<2> &pa, const PrimitiveHandle<2> &pb) -> bool
 {
@@ -222,8 +228,7 @@ _intersects(const PrimitiveHandle<2> &pa, const PrimitiveHandle<2> &pb) -> bool
   return false;
 }
 
-//
-// intersects of a volume with any other type
+/// intersects of a volume with any other type
 struct intersects_volume_x : public boost::static_visitor<bool> {
   const MarkedPolyhedron *polyhedron;
 
@@ -269,8 +274,7 @@ struct intersects_volume_x : public boost::static_visitor<bool> {
   }
 };
 
-//
-// Type of pa must be of larger dimension than type of pb
+/// Type of pa must be of larger dimension than type of pb
 auto
 _intersects(const PrimitiveHandle<3> &pa, const PrimitiveHandle<3> &pb) -> bool
 {
@@ -335,6 +339,13 @@ dispatch_intersects_sym(const PrimitiveHandle<Dim> &pa,
   return _intersects(pb, pa);
 }
 
+/// @} end of private section
+
+// ----------------------------------------------------------------------------------
+// -- public interface
+// ----------------------------------------------------------------------------------
+/// @publicsection
+
 template <int Dim>
 auto
 intersects(const PrimitiveHandle<Dim> &pa, const PrimitiveHandle<Dim> &pb)
@@ -379,13 +390,17 @@ intersects(const GeometrySet<Dim> &a, const GeometrySet<Dim> &b) -> bool
   return false;
 }
 
+/// @private
 template bool
 intersects<2>(const GeometrySet<2> &a, const GeometrySet<2> &b);
+/// @private
 template bool
 intersects<3>(const GeometrySet<3> &a, const GeometrySet<3> &b);
 
+/// @private
 template bool
 intersects<2>(const PrimitiveHandle<2> &a, const PrimitiveHandle<2> &b);
+/// @private
 template bool
 intersects<3>(const PrimitiveHandle<3> &a, const PrimitiveHandle<3> &b);
 
@@ -433,6 +448,7 @@ intersects3D(const Geometry &ga, const Geometry &gb, NoValidityCheck /*unused*/)
   return intersects(gsa, gsb);
 }
 
+/// @private
 template <int Dim>
 auto
 selfIntersectsImpl(const LineString &line) -> bool
@@ -525,18 +541,19 @@ selfIntersects3D(const LineString &l) -> bool
   return selfIntersectsImpl<3>(l);
 }
 
+/// @private
 template <int Dim>
 auto
 selfIntersectsImpl(const PolyhedralSurface &s, const SurfaceGraph &graph)
     -> bool
 {
-  size_t const numPolygons = s.numPolygons();
+  size_t const numPatches = s.numPatches();
 
-  for (size_t pi = 0; pi != numPolygons; ++pi) {
-    for (size_t pj = pi + 1; pj < numPolygons; ++pj) {
+  for (size_t pi = 0; pi != numPatches; ++pi) {
+    for (size_t pj = pi + 1; pj < numPatches; ++pj) {
       std::unique_ptr<Geometry> inter =
-          Dim == 3 ? intersection3D(s.polygonN(pi), s.polygonN(pj))
-                   : intersection(s.polygonN(pi), s.polygonN(pj));
+          Dim == 3 ? intersection3D(s.patchN(pi), s.patchN(pj))
+                   : intersection(s.patchN(pi), s.patchN(pj));
 
       if (!inter->isEmpty()) {
         // two cases:
@@ -579,18 +596,19 @@ selfIntersects3D(const PolyhedralSurface &s, const SurfaceGraph &g) -> bool
   return selfIntersectsImpl<3>(s, g);
 }
 
+/// @private
 template <int Dim>
 auto
 selfIntersectsImpl(const TriangulatedSurface &tin, const SurfaceGraph &graph)
     -> bool
 {
-  size_t const numTriangles = tin.numTriangles();
+  size_t const numPatches = tin.numPatches();
 
-  for (size_t ti = 0; ti != numTriangles; ++ti) {
-    for (size_t tj = ti + 1; tj < numTriangles; ++tj) {
+  for (size_t ti = 0; ti != numPatches; ++ti) {
+    for (size_t tj = ti + 1; tj < numPatches; ++tj) {
       std::unique_ptr<Geometry> inter =
-          Dim == 3 ? intersection3D(tin.triangleN(ti), tin.triangleN(tj))
-                   : intersection(tin.triangleN(ti), tin.triangleN(tj));
+          Dim == 3 ? intersection3D(tin.patchN(ti), tin.patchN(tj))
+                   : intersection(tin.patchN(ti), tin.patchN(tj));
 
       if (!inter->isEmpty()) {
         // two cases:
