@@ -5,6 +5,8 @@
 
 #include "SFCGAL/GeometryCollection.h"
 #include "SFCGAL/Polygon.h"
+#include "SFCGAL/algorithm/isValid.h"
+#include "SFCGAL/algorithm/orientation.h"
 
 #include "SFCGAL/detail/GetPointsVisitor.h"
 
@@ -21,6 +23,11 @@
 
 namespace SFCGAL::algorithm {
 
+// ----------------------------------------------------------------------------------
+// -- private interface
+// ----------------------------------------------------------------------------------
+/// @{
+/// @privatesection
 using Traits     = CGAL::Partition_traits_2<Kernel>;
 using TPoint_2   = Traits::Point_2;
 using TPolygon_2 = Traits::Polygon_2;
@@ -57,6 +64,9 @@ toTPolygon_2(const Polygon &poly) -> CGAL::Partition_traits_2<Kernel>::Polygon_2
 
   TPolygon_2 result(points.begin(), points.end());
 
+  if (result.orientation() != CGAL::COUNTERCLOCKWISE) {
+    result.reverse_orientation();
+  }
   return result;
 }
 
@@ -79,9 +89,16 @@ polygons_to_geometry(const std::list<TPolygon_2> &polys)
   return std::unique_ptr<Geometry>(geoms);
 }
 
+/// @} end of private section
+
+// ----------------------------------------------------------------------------------
+// -- public interface
+// ----------------------------------------------------------------------------------
+/// @publicsection
+
 auto
-partition_2(const Geometry &g, PartitionAlgorithm alg)
-    -> std::unique_ptr<Geometry>
+partition_2(const Geometry &g, PartitionAlgorithm alg,
+            NoValidityCheck /*unused*/) -> std::unique_ptr<Geometry>
 {
   using CGAL::object_cast;
 
@@ -119,4 +136,12 @@ partition_2(const Geometry &g, PartitionAlgorithm alg)
   return polygons_to_geometry(partition_polys);
 }
 
+auto
+partition_2(const Geometry &g, PartitionAlgorithm alg)
+    -> std::unique_ptr<Geometry>
+{
+  SFCGAL_ASSERT_GEOMETRY_VALIDITY_2D(g);
+  return partition_2(g, alg, NoValidityCheck());
+}
+
 } // namespace SFCGAL::algorithm
