@@ -18,11 +18,7 @@
 
 namespace SFCGAL::generator {
 
-using Point_2              = Kernel::Point_2;
-using Point_3              = Kernel::Point_3;
-using Polygon_2            = CGAL::Polygon_2<Kernel>;
-using Polygon_with_holes_2 = CGAL::Polygon_with_holes_2<Kernel>;
-using Straight_skeleton_2  = CGAL::Straight_skeleton_2<Kernel>;
+using Straight_skeleton_2 = CGAL::Straight_skeleton_2<Kernel>;
 
 /**
  * @brief Basic building generator relying on a straight skeleton
@@ -57,9 +53,6 @@ _buildingWall(const Polygon_2 &ring, const Kernel::FT &wallHeight,
   }
 }
 
-///
-///
-///
 auto
 building(const Polygon &g, const Kernel::FT &wallHeight,
          const Kernel::FT &roofSlope) -> std::unique_ptr<Geometry>
@@ -136,9 +129,6 @@ building(const Polygon &g, const Kernel::FT &wallHeight,
   return std::unique_ptr<Geometry>(new Solid(shell.release()));
 }
 
-///
-///
-///
 auto
 building(const MultiPolygon &g, const Kernel::FT &wallHeight,
          const Kernel::FT &roofSlope) -> std::unique_ptr<Geometry>
@@ -153,9 +143,6 @@ building(const MultiPolygon &g, const Kernel::FT &wallHeight,
   return std::unique_ptr<Geometry>(multiSolid.release());
 }
 
-///
-///
-///
 auto
 building(const Geometry &g, const Kernel::FT &wallHeight,
          const Kernel::FT &roofSlope) -> std::unique_ptr<Geometry>
